A port represents a virtual switch port on a logical network switch.

Ports can be created under a network by administrators.

Containers attach their interfaces to ports.

The logical port also defines the MAC address and the IP address(es) to be assigned to the interfaces plugged into them.

When IP addresses are associated to a port, this also implies the port is associated with a subnet, as the IP address was taken from the allocation pool for a specific subnet.

When the Admin State for a port is set to Up and it has no Device Owner, then the port is available for use. You can set the Admin State to Down if you are not ready for other users to use the port.

The status indicates whether the port has an active connection.